==> open-xchange-appsuite_7.8.2.orig.tar.bz2: open-xchange-appsuite-7.8.2/ui/apps/io.ox/files/actions/save-as-pdf.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH, Germany. info@open-xchange.com
 *
 * @author Peter Seliger <peter.seliger@open-xchange.com>
 */

define('io.ox/files/actions/save-as-pdf', [

    'io.ox/core/folder/api',
    'io.ox/files/api',
    'io.ox/files/util',

    'io.ox/presenter/errormessages',

    'io.ox/core/extensions',
    'io.ox/core/tk/dialogs',
    'io.ox/core/tk/doc-converter-utils',

    'gettext!io.ox/files'

], function (FolderApi, FilesApi, FilesUtil, ErrorMessages, ext, dialogs, ConverterUtils, gt) {

    'use strict';

    return function (baton) {

//      newFileName = oldFileName;
//      title = gt('Save as PDF');
//
//      // create the dialog
//      dialog = new Dialogs.SaveAsFileDialog({ title: title, value: newFileName, preselect: app.getFileParameters().folder_id });

        var
        //  data     = baton.data,
            model    = baton.models[0],

            isAccessWrite = FolderApi.can('create', FolderApi.pool.models[model.get('folder_id')].toJSON()),

        //  filename = model.getDisplayName() + '.pdf';
            filename = model.getDisplayName(),

            len      = filename.length,
            idx      = filename.lastIndexOf('.');

        filename = filename.substring(0, ((idx >= 0) ? idx : len)) + '.pdf';

      //console.log('+++ io.ox/files/actions/save-as-pdf :: data, model, filename : ', data, model, filename);
      //console.log('+++ io.ox/files/actions/save-as-pdf :: isAccessWrite : ', isAccessWrite);

        function save(name) {
            return ConverterUtils.sendConverterRequest(model, {

                documentformat: 'pdf',
                saveas_filename: name,
              //saveas_folder_id: model.get('folder_id')
                saveas_folder_id: (isAccessWrite ? model.get('folder_id') : require('settings!io.ox/files').get('folder/documents'))

            }).done(function (response) {
              //console.log('+++ save as pdf :: done - response : ', response);

                if (('id' in response) && ('filename' in response)) {

                    FilesApi.trigger('add:file');

                    if (!isAccessWrite) {
                        notify('info', 'The PDF has been saved to "/drive/myfiles/documents" due to not having write access for the current folder.');
                    }
                } else {
                    notify('error', ErrorMessages.getConversionErrorMessage(response));
                }
            });
        }

        // notifications lazy load
        function notify() {
            var self = this, args = arguments;
            require(['io.ox/core/notifications'], function (notifications) {
                notifications.yell.apply(self, args);
            });
        }

        /**
         * user have to confirm if name doesn't contains a file extension
         * @return { promise }
         */
        function process(name) {

            var invalid;

            // taken and refactored from 'io.ox/files/actions/rename'
            // TODO - Olpe please check if processing of `invalid` does ever take place - I doubt it though.
            //
            // check for valid filename
            ext.point('io.ox/core/filename')
                .invoke('validate', null, name, 'file')
                .find(function (result) {
                    if (result !== true) {
                        notify('warning', result);
                        return (invalid = true);
                    }
                });

            if (invalid) return $.Deferred().reject();

            // show confirm dialog if necessary
            return FilesUtil.confirmDialog(name, filename).then(save.bind(this, name));
        }

        new dialogs.ModalDialog({ enter: 'save', async: true })
            .header(
                $('<h4>').text(gt('Save as PDF'))
            )
            .append(
                $('<input type="text" name="name" class="form-control" tabindex="1">')
            )
            .addPrimaryButton('save', gt('Save'), 'save', { 'tabIndex': '1' })
            .addButton('cancel', gt('Cancel'), 'cancel', { 'tabIndex': '1' })
            .on('save', function () {
                var node = this.getContentNode(),
                    name = node.find('input[name="name"]').val();

                process(name).then(this.close, this.idle).fail(function () {
                    _.defer(function () { node.focus(); });
                });
            })
            .show(function () {
                this.find('input[name="name"]')
                    .focus().val(filename)
                    .get(0).setSelectionRange(0, filename.lastIndexOf('.'));
            });

    };
});

==> open-xchange-appsuite_7.8.3.orig.tar.bz2: open-xchange-appsuite-7.8.3/ui/apps/io.ox/files/actions/save-as-pdf.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH, Germany. info@open-xchange.com
 *
 * @author Peter Seliger <peter.seliger@open-xchange.com>
 */

define('io.ox/files/actions/save-as-pdf', [

    'io.ox/core/folder/api',
    'io.ox/files/api',
    'io.ox/files/util',

    'io.ox/presenter/errormessages',

    'io.ox/core/extensions',
    'io.ox/core/tk/dialogs',
    'io.ox/core/tk/doc-converter-utils',

    'gettext!io.ox/files'

], function (FolderApi, FilesApi, FilesUtil, ErrorMessages, ext, dialogs, ConverterUtils, gt) {

    'use strict';

    return function (baton) {

//      newFileName = oldFileName;
//      title = gt('Save as PDF');
//
//      // create the dialog
//      dialog = new Dialogs.SaveAsFileDialog({ title: title, value: newFileName, preselect: app.getFileParameters().folder_id });

        var
        //  data     = baton.data,
            model    = baton.models[0],

            isAccessWrite = FolderApi.can('create', FolderApi.pool.models[model.get('folder_id')].toJSON()),

            filename = model.getDisplayName(),

            len      = filename.length,
            idx      = filename.lastIndexOf('.');

        filename = filename.substring(0, ((idx >= 0) ? idx : len));

      //console.log('+++ io.ox/files/actions/save-as-pdf :: data, model, filename : ', data, model, filename);
      //console.log('+++ io.ox/files/actions/save-as-pdf :: isAccessWrite : ', isAccessWrite);

        function save(name) {
            return ConverterUtils.sendConverterRequest(model, {

                documentformat: 'pdf',
                saveas_filename: name + '.pdf',
              //saveas_folder_id: model.get('folder_id')
                saveas_folder_id: (isAccessWrite ? model.get('folder_id') : require('settings!io.ox/files').get('folder/documents'))

            }).done(function (response) {
              //console.log('+++ save as pdf :: done - response : ', response);

                if (('id' in response) && ('filename' in response)) {

                    FilesApi.trigger('add:file');

                    if (!isAccessWrite) {
                        notify('info', 'The PDF has been saved to "/drive/myfiles/documents" due to not having write access for the current folder.');
                    }
                } else {
                    notify('error', ErrorMessages.getConversionErrorMessage(response));
                }
            });
        }

        // notifications lazy load
        function notify() {
            var self = this, args = arguments;
            require(['io.ox/core/notifications'], function (notifications) {
                notifications.yell.apply(self, args);
            });
        }

        /**
         * user have to confirm if name doesn't contains a file extension
         * @return { promise }
         */
        function process(name) {

            var invalid;

            // taken and refactored from 'io.ox/files/actions/rename'
            // TODO - Olpe please check if processing of `invalid` does ever take place - I doubt it though.
            //
            // check for valid filename
            ext.point('io.ox/core/filename')
                .invoke('validate', null, name, 'file')
                .find(function (result) {
                    if (result !== true) {
                        notify('warning', result);
                        return (invalid = true);
                    }
                });

            if (invalid) return $.Deferred().reject();

            // show confirm dialog if necessary
            return FilesUtil.confirmDialog(name, filename).then(save.bind(this, name));
        }

        new dialogs.ModalDialog({ enter: 'save', async: true })
            .header(
                $('<h4>').text(gt('Save as PDF'))
            )
            .append(
                $('<input type="text" name="name" class="form-control">')
            )
            .addPrimaryButton('save', gt('Save'), 'save')
            .addButton('cancel', gt('Cancel'), 'cancel')
            .on('save', function () {
                var node = this.getContentNode(),
                    name = node.find('input[name="name"]').val();

                process(name).then(this.close, this.idle).fail(function () {
                    _.defer(function () { node.focus(); });
                });
            })
            .show(function () {
                this.find('input[name="name"]')
                    .focus().val(filename)
                    .get(0).setSelectionRange(0, filename.lastIndexOf('.'));
            });

    };
});
